pub struct AppointmentSlotReport {
pub scheduling_type: Option<SchedulingType>,
pub start_time: Option<String>,
pub end_time: Option<String>,
pub appointment_slots: Option<Vec<AppointmentSlot>>,
}Expand description
AppointmentSlotReport : Availability information as per the service context queried.
Fields
scheduling_type: Option<SchedulingType>Defines the type of slots.
start_time: Option<String>Start Time from which the appointment slots are generated in ISO 8601 format.
end_time: Option<String>End Time up to which the appointment slots are generated in ISO 8601 format.
appointment_slots: Option<Vec<AppointmentSlot>>A list of time windows along with associated capacity in which the service can be performed.
Implementations
sourceimpl AppointmentSlotReport
impl AppointmentSlotReport
sourcepub fn new() -> AppointmentSlotReport
pub fn new() -> AppointmentSlotReport
Availability information as per the service context queried.